/* H5400 Fingerprint Sensor Interface client library
 * Copyright (c) 2004 Jrgen Andreas Michaelsen <jorgenam@ifi.uio.no> 
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version
 * 2 of the License, or (at your option) any later version.
 */

#ifndef _fsiclient_h
#define _fsiclient_h

#define FSI_DEV_NAME            "/dev/misc/fsi"

#define FSI_FRAME_SIZE          281
#define FSI_FRAME_SIZE_BYTES    (FSI_FRAME_SIZE*4)
#define FSI_FRAME_WIDTH         (FSI_FRAME_SIZE-1)
#define FSI_FRAME_HEIGHT        8

#define FSI_ERROR_MAGIC         0x230000
#define FSI_ERROR_OPEN          (FSI_ERROR_MAGIC|0x1000)
#define FSI_ERROR_READ          (FSI_ERROR_MAGIC|0x2000)
#define FSI_ERROR_CLOSE         (FSI_ERROR_MAGIC|0x3000)
#define FSI_ERROR_IOCTL         (FSI_ERROR_MAGIC|0x4000)
#define FSI_ERROR_SYNC          (FSI_ERROR_MAGIC|0x5000)

#define FSI_DB1_EVEN(x)         (x&0xF)
#define FSI_DB1_ODD(x)          ((x>>4)&0xF)
#define FSI_DB2_EVEN(x)         ((x>>8)&0xF)
#define FSI_DB2_ODD(x)          ((x>>12)&0xF)
#define FSI_DB3_EVEN(x)         ((x>>16)&0xF)
#define FSI_DB3_ODD(x)          ((x>>20)&0xF)
#define FSI_DB4_EVEN(x)         ((x>>24)&0xF)
#define FSI_DB4_ODD(x)          ((x>>28)&0xF)

#ifdef __cplusplus
extern "C" {
#endif

struct fsi_error
{
  char string[255];             /* library function that generated error */
  unsigned int code;            /* error code */
};

struct fsi_context
{
  int fd;
  unsigned long *frames_buffer;
  unsigned int frame_count;
  unsigned int line_count;
  unsigned int line_width;
  unsigned int temperature;
  unsigned int quality;
  unsigned int speed;

  struct fsi_error err;
};


char *fsi_get_error_string( struct fsi_context *ctx );
int fsi_init( struct fsi_context *ctx );
int fsi_read_frames( struct fsi_context *ctx, unsigned long *frames_buffer, unsigned int buffer_size );
int fsi_merge_frames( struct fsi_context *ctx );
int fsi_release( struct fsi_context *ctx );
unsigned int fsi_get_line_count( struct fsi_context *ctx );
unsigned int fsi_get_line_width( struct fsi_context *ctx );
int fsi_get_temperature( struct fsi_context *ctx );
unsigned int fsi_get_quality( struct fsi_context *ctx );

#ifdef __cplusplus
}
#endif

#endif /* _fsiclient_h */
