/* H5400 Fingerprint Sensor Interface client library usage example
 * Copyright (c) 2004 Jrgen Andreas Michaelsen <jorgenam@ifi.uio.no> 
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version
 * 2 of the License, or (at your option) any later version.
 */

#include <time.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>

#include "fsiclient.h"

#define BUF_SIZE  (FSI_FRAME_SIZE_BYTES * 512)


int main( int argc, char **argv )
{
  int result;
  void *buffer;
  char fname[256];
  FILE *fp;
  size_t wcount;
  struct fsi_context ctx;


  if( argc > 2 )
    return 1;
  if( argc == 2 )
    strncpy( fname, argv[1], sizeof(fname) );
  else
    sprintf( fname, "fp_%08lx.raw", time(NULL) );

  buffer = malloc( BUF_SIZE );
  if( buffer == NULL )
    {
      fprintf( stderr, "malloc failed\n" );
      return 9;
    }

  result = fsi_init( &ctx );
  if( result < 0 )
    {
      fprintf( stderr, "%s\n", fsi_get_error_string(&ctx) );
      return 1;
    }
  
  printf( "swipe finger... " ); fflush( stdout );
  
  result = fsi_read_frames( &ctx, buffer, BUF_SIZE );
  if( result < 0 )
    {
      fprintf( stderr, "%s\n", fsi_get_error_string(&ctx) );
      return 2;
    }
  
  printf( "OK [dT=%d mK]\n", fsi_get_temperature(&ctx) );
  printf( "dumping raw fingerprint frames... " ); fflush( stdout );
  
  fp = fopen( fname, "wb" );
  if( fp == NULL )
    return 4;
  
  wcount = fwrite( buffer, FSI_FRAME_SIZE_BYTES, ctx.frame_count, fp );
  printf( "OK [wcount=%d,frame_count=%d]\n", wcount, ctx.frame_count );

  fclose( fp );
}
